Package: roxygen2
Title: In-Line Documentation for R
Version: 6.1.0
Authors@R: c(
    person("Hadley", "Wickham",, "hadley@rstudio.com", c("aut", "cre", "cph")),
    person("Peter", "Danenberg",, "pcd@roxygen.org", c("aut", "cph")),
    person("Manuel", "Eugster", role = c("aut", "cph")),
    person("RStudio", role = "cph")
    )
Description: Generate your Rd documentation, 'NAMESPACE' file, and collation 
    field using specially formatted comments. Writing documentation in-line
    with code makes it easier to keep your documentation up-to-date as your
    requirements change. 'Roxygen2' is inspired by the 'Doxygen' system for C++.
License: GPL (>= 2)
URL: https://github.com/klutometis/roxygen
BugReports: https://github.com/klutometis/roxygen/issues
Depends: R (>= 3.1)
Imports: brew, commonmark, desc, digest, methods, pkgload, purrr, R6
        (>= 2.1.2), Rcpp (>= 0.11.0), stringi, stringr (>= 1.0.0),
        utils, xml2
Suggests: covr, devtools, knitr, rmarkdown, testthat (>= 0.8.0)
LinkingTo: Rcpp
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 6.0.1.9000
NeedsCompilation: yes
Packaged: 2018-07-25 20:48:13 UTC; hadley
Author: Hadley Wickham [aut, cre, cph],
  Peter Danenberg [aut, cph],
  Manuel Eugster [aut, cph],
  RStudio [cph]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Repository: CRAN
Date/Publication: 2018-07-27 21:10:02 UTC
Built: R 3.4.1; x86_64-w64-mingw32; 2018-09-21 06:13:32 UTC; windows
Archs: x64
