# Generated by roxygen2: do not edit by hand

S3method(c,rd)
S3method(default_export,"NULL")
S3method(default_export,default)
S3method(default_export,rcclass)
S3method(default_export,s3method)
S3method(default_export,s4class)
S3method(default_export,s4generic)
S3method(default_export,s4method)
S3method(format,roxy_field)
S3method(format,roxy_field_alias)
S3method(format,roxy_field_author)
S3method(format,roxy_field_backref)
S3method(format,roxy_field_concept)
S3method(format,roxy_field_description)
S3method(format,roxy_field_details)
S3method(format,roxy_field_docType)
S3method(format,roxy_field_encoding)
S3method(format,roxy_field_examples)
S3method(format,roxy_field_family)
S3method(format,roxy_field_field)
S3method(format,roxy_field_formals)
S3method(format,roxy_field_format)
S3method(format,roxy_field_inherit)
S3method(format,roxy_field_inherit_dot_params)
S3method(format,roxy_field_inherit_section)
S3method(format,roxy_field_keyword)
S3method(format,roxy_field_minidesc)
S3method(format,roxy_field_name)
S3method(format,roxy_field_note)
S3method(format,roxy_field_param)
S3method(format,roxy_field_rawRd)
S3method(format,roxy_field_rcmethods)
S3method(format,roxy_field_reexport)
S3method(format,roxy_field_references)
S3method(format,roxy_field_section)
S3method(format,roxy_field_seealso)
S3method(format,roxy_field_slot)
S3method(format,roxy_field_source)
S3method(format,roxy_field_title)
S3method(format,roxy_field_usage)
S3method(format,roxy_field_value)
S3method(merge,roxy_field)
S3method(merge,roxy_field_inherit)
S3method(merge,roxy_field_inherit_dot_params)
S3method(merge,roxy_field_inherit_section)
S3method(merge,roxy_field_minidesc)
S3method(merge,roxy_field_reexport)
S3method(merge,roxy_field_section)
S3method(obj_type,MethodDefinition)
S3method(obj_type,classRepresentation)
S3method(obj_type,default)
S3method(obj_type,genericFunction)
S3method(obj_type,package)
S3method(obj_type,refClassRepresentation)
S3method(obj_type,refMethodDef)
S3method(obj_type,s3generic)
S3method(obj_type,s3method)
S3method(object_defaults,data)
S3method(object_defaults,default)
S3method(object_defaults,import)
S3method(object_defaults,package)
S3method(object_defaults,rcclass)
S3method(object_defaults,s4class)
S3method(object_defaults,s4method)
S3method(object_format,default)
S3method(print,object)
S3method(print,rd)
S3method(print,roxy_field)
S3method(print,roxy_tag)
S3method(roclet_clean,roclet_namespace)
S3method(roclet_clean,roclet_rd)
S3method(roclet_output,roclet_namespace)
S3method(roclet_output,roclet_rd)
S3method(roclet_output,roclet_vignette)
S3method(roclet_process,roclet_namespace)
S3method(roclet_process,roclet_rd)
S3method(roclet_process,roclet_vignette)
S3method(roclet_tags,roclet_namespace)
S3method(roclet_tags,roclet_rd)
S3method(roclet_tags,roclet_vignette)
export(is_s3_generic)
export(is_s3_method)
export(load_options)
export(namespace_roclet)
export(object)
export(object_format)
export(rd_roclet)
export(roc_proc_text)
export(roclet)
export(roclet_clean)
export(roclet_find)
export(roclet_output)
export(roclet_process)
export(roclet_tags)
export(roxy_tag)
export(roxy_tag_warning)
export(roxygenise)
export(roxygenize)
export(tag_code)
export(tag_examples)
export(tag_inherit)
export(tag_markdown)
export(tag_markdown_restricted)
export(tag_name)
export(tag_name_description)
export(tag_toggle)
export(tag_two_part)
export(tag_value)
export(tag_words)
export(tag_words_line)
export(update_collate)
export(vignette_roclet)
import(stringr)
importFrom(R6,R6Class)
importFrom(Rcpp,sourceCpp)
importFrom(commonmark,markdown_xml)
importFrom(methods,is)
importFrom(stats,setNames)
importFrom(utils,URLdecode)
importFrom(utils,URLencode)
importFrom(xml2,read_xml)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_children)
importFrom(xml2,xml_contents)
importFrom(xml2,xml_name)
importFrom(xml2,xml_text)
importFrom(xml2,xml_type)
useDynLib(roxygen2)
